pub struct ListOrSet { /* private fields */ }Expand description
Corresponds to the Smithy List and Set top-level shapes. It has a single member, named member
which determines the shape type for each member of the list.
Implementations
Sourceimpl ListOrSet
impl ListOrSet
Sourcepub fn new(member_target: ShapeID) -> Self
pub fn new(member_target: ShapeID) -> Self
Construct a new list, or set, with the given ShapeID as the reference to the member type.
Sourcepub fn from(member: MemberShape) -> Self
pub fn from(member: MemberShape) -> Self
Construct a new list, or set, with the given value as the member.
Sourcepub fn member(&self) -> &MemberShape
pub fn member(&self) -> &MemberShape
Return the identifier for the type of each member of the list or set.
Sourcepub fn set_member(&mut self, member: MemberShape)
pub fn set_member(&mut self, member: MemberShape)
Set the identifier of the type of each member of the list or set.